PrayTime class

Constructors

PrayTime({int method = Karachi})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeTime(dynamic G, double t) → double
floatToTime12(double time, {bool suffix = true}) → String
floatToTime24(double time) → String
getDatePrayerTimes(int year, int month, int day, double latitude, double longitude, double timeZone) → List<String>
getPrayerTimes(Map<String, int> date, double latitude, double longitude, double timeZone) → List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sunPosition(double jd) → Map<String, double>
timeDiff(double time1, double time2) → double
toString() → String
A string representation of this object.
inherited
twoDigitsFormat(int num) → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited